@@ -1,6 +1,7 @@
 #ifndef PLANETPROPERTIES_H
 #define PLANETPROPERTIES_H
 
+#include <cstring>
 #include <string>
 #include <vector>
 
@@ -17,12 +18,18 @@ class PlanetProperties
     const unsigned char * ArcColor() const { return(arcColor_); };
     void ArcColor(unsigned char color[3]) { memcpy(arcColor_, color, 3); };
 
+    const int ArcThickness() const { return(arcThickness_); };
+    void ArcThickness(const int thickness) { arcThickness_ = thickness; };
+
     const std::string & BumpMap() const           { return(bumpMap_); };
     void BumpMap(const std::string &b) { bumpMap_ = b; };
 
     double BumpScale() const { return(bumpScale_); };
     void BumpScale(double b) { bumpScale_ = b; };
 
+    double BumpShade() const { return(bumpShade_); };
+    void BumpShade(double s) { bumpShade_ = s; };
+
     double CloudGamma() const { return(cloudGamma_); };
     void CloudGamma(double c) { cloudGamma_ = c; };
 
@@ -58,6 +65,7 @@ class PlanetProperties
 
     const unsigned char * OrbitColor() const { return(orbitColor_); };
     void OrbitColor(unsigned char color[3]) { memcpy(orbitColor_, color, 3); };
+
     const unsigned char * TextColor() const { return(textColor_); };
     void TextColor(unsigned char color[3]) { memcpy(textColor_, color, 3); };
 
@@ -75,13 +83,13 @@ class PlanetProperties
 
     bool MapBounds() const { return(mapBounds_); };
     void MapBounds(double &uly, double &ulx, 
-		   double &lry, double &lrx) const
+                   double &lry, double &lrx) const
         {
             uly = mapUly_; ulx = mapUlx_; lry = mapLry_; lrx = mapLrx_;
         };
     
     void MapBounds(bool b, double uly, double ulx, 
-		   double lry, double lrx)
+                   double lry, double lrx)
         {
             mapBounds_ = b; mapUly_ = uly; mapUlx_ = ulx; mapLry_ = lry; mapLrx_ = lrx;
         };
@@ -116,6 +124,18 @@ class PlanetProperties
     bool RandomTarget() const { return(randomTarget_); };
     void RandomTarget(bool b) { randomTarget_ = b; };
 
+    void RayleighEmissionWeight(double r) { rayleighEmissionWeight_ = r; };
+    double RayleighEmissionWeight() { return rayleighEmissionWeight_; };
+
+    void RayleighFile(const std::string &rayleighFile) { rayleighFile_ = rayleighFile; };
+    const std::string & RayleighFile() const { return rayleighFile_; };
+
+    void RayleighLimbScale(double r) { rayleighLimbScale_ = r; };
+    double RayleighLimbScale() { return rayleighLimbScale_; };
+
+    void RayleighScale(double r) { rayleighScale_ = r; };
+    double RayleighScale() { return rayleighScale_; };
+
     double Shade() const { return(shade_); };
     void Shade(double s) { shade_ = s; };
 
@@ -138,9 +158,11 @@ class PlanetProperties
     unsigned char arcColor_[3];
 
     std::vector<std::string> arcFiles_;
+    int arcThickness_;
 
     std::string bumpMap_;
     double bumpScale_;
+    double bumpShade_;
 
     double cloudGamma_;
     std::string cloudMap_;
@@ -179,6 +201,11 @@ class PlanetProperties
     bool randomOrigin_;
     bool randomTarget_;
 
+    double rayleighEmissionWeight_;
+    std::string rayleighFile_;
+    double rayleighLimbScale_;
+    double rayleighScale_;
+
     std::vector<std::string> satelliteFiles_;
 
     bool ssecMap_;
@@ -192,8 +219,8 @@ class PlanetProperties
     unsigned char textColor_[3];
 
     double twilight_;    // if the sun is within twilight degrees of
-			 // the horizon, blend the day and night
-			 // images together
+                         // the horizon, blend the day and night
+                         // images together
 };
 
 #endif
