@@ -14,7 +14,7 @@ enum keyWords
     HEMISPHERE, HIBERNATE,
     ICOSAGNOMONIC, IDLEWAIT, IMAGE, INTERPOLATE_ORIGIN_FILE,
     JDATE, JPL_FILE, 
-    LABEL, LABELPOS, LABEL_BODY, LABEL_STRING, LAMBERT, LANGUAGE, LATITUDE, LATLON, LBR, LEFT, LIGHT_TIME, LOCALTIME, LOGMAGSTEP, LONGITUDE, 
+    LABEL, LABELPOS, LABEL_ALTITUDE, LABEL_BODY, LABEL_STRING, LAMBERT, LANGUAGE, LATITUDE, LATLON, LBR, LEFT, LIGHT_TIME, LOCALTIME, LOGMAGSTEP, LONGITUDE, 
     MAGNIFY, MAJOR, MAKECLOUDMAPS, MAP_BOUNDS, MARKER_BOUNDS, MARKER_COLOR, MARKER_FILE, MARKER_FONT, MARKER_FONTSIZE, MAX_RAD_FOR_LABEL, MIN_RAD_FOR_LABEL, MAX_RAD_FOR_MARKERS, MIN_RAD_FOR_MARKERS, MERCATOR, MOLLWEIDE, MULTIPLE,
     NAME, NIGHT_MAP, NORTH, NUM_TIMES, 
     OPACITY, ORBIT, ORBIT_COLOR, ORIGIN, ORIGINFILE, ORTHOGRAPHIC, OUTLINED, OUTPUT, OUTPUT_MAP_RECT, OUTPUT_START_INDEX, 
@@ -43,7 +43,7 @@ const char * const keyWordString[LAST_WORD] =
     "HEMISPHERE", "HIBERNATE",
     "ICOSAGNOMONIC", "IDLEWAIT", "IMAGE", "INTERPOLATE_ORIGIN_FILE",
     "JDATE", "JPL_FILE", 
-    "LABEL", "LABELPOS", "LABEL_BODY", "LABEL_STRING", "LAMBERT", "LANGUAGE", "LATITUDE", "LATLON", "LBR", "LEFT", "LIGHT_TIME", "LOCALTIME", "LOGMAGSTEP", "LONGITUDE", 
+    "LABEL", "LABELPOS", "LABEL_ALTITUDE", "LABEL_BODY", "LABEL_STRING", "LAMBERT", "LANGUAGE", "LATITUDE", "LATLON", "LBR", "LEFT", "LIGHT_TIME", "LOCALTIME", "LOGMAGSTEP", "LONGITUDE", 
     "MAGNIFY", "MAJOR", "MAKECLOUDMAPS", "MAP_BOUNDS", "MARKER_BOUNDS", "MARKER_COLOR", "MARKER_FILE", "MARKER_FONT", "MARKER_FONTSIZE", "MAX_RAD_FOR_LABEL", "MIN_RAD_FOR_LABEL", "MAX_RAD_FOR_MARKERS", "MIN_RAD_FOR_MARKERS", "MERCATOR", "MOLLWEIDE", "MULTIPLE",
     "NAME", "NIGHT_MAP", "NORTH", "NUM_TIMES", 
     "OPACITY", "ORBIT", "ORBIT_COLOR", "ORIGIN", "ORIGINFILE", "ORTHOGRAPHIC", "OUTLINED", "OUTPUT", "OUTPUT_MAP_RECT", "OUTPUT_START_INDEX", 
