@@ -21,8 +21,8 @@ using namespace std;
 
 DisplayMSWin::DisplayMSWin(const int tr) : DisplayBase(tr)
 {
-    fullWidth_ = GetSystemMetrics(SM_CXSCREEN);
-    fullHeight_ = GetSystemMetrics(SM_CYSCREEN);
+    fullWidth_ = GetSystemMetrics(SM_CXVIRTUALSCREEN);
+    fullHeight_ = GetSystemMetrics(SM_CYVIRTUALSCREEN);
 
     Options *options = Options::getInstance();
     switch (options->DisplayMode())
@@ -71,7 +71,7 @@ DisplayMSWin::renderImage(PlanetProperties *planetProperties[])
     drawLabel(planetProperties);
 
     string outputFilename(TmpDir());
-    outputFilename += "\\XPlanet.bmp";
+    outputFilename += "\\XPlanet.png";
 
     Options *options = Options::getInstance();
     if (options->GeometrySelected()) PlaceImageOnRoot();
@@ -95,9 +95,6 @@ DisplayMSWin::renderImage(PlanetProperties *planetProperties[])
     SystemParametersInfo(SPI_SETDESKWALLPAPER, 0, 
                          (char *) outputFilename.c_str(), 
                          SPIF_UPDATEINIFILE);
-
-    if (!options->SaveDesktopFile())
-        unlinkFile(outputFilename.c_str());
 }
 
 string
@@ -109,7 +106,7 @@ DisplayMSWin::TmpDir()
     if (returnstring.empty())
     {
         char tmpdir[MAX_PATH];
-        GetWindowsDirectory(tmpdir, MAX_PATH);
+        GetTempPath(MAX_PATH, tmpdir);
         returnstring.assign(tmpdir);
     }
     return(returnstring);
