@@ -850,8 +850,7 @@ double
 Planet::Radius(const double lat) const
 {
     double returnValue = 1;
-    if (index_ == JUPITER ||
-        index_ == SATURN)
+    if (index_ == JUPITER || index_ == SATURN)
     {
         double tmpLat = lat;
         double tmpLon = 0;
