@@ -176,6 +176,8 @@ parse(int &i, const char *line, char *&returnString)
         returnVal = BUMP_MAP;
     else if (getValue(line, i, "bump_scale=", returnString))
         returnVal = BUMP_SCALE;
+    else if (getValue(line, i, "bump_shade=", returnString))
+        returnVal = BUMP_SHADE;
     else if (getValue(line, i, "cloud_gamma=", returnString))
         returnVal = CLOUD_GAMMA;
     else if (getValue(line, i, "cloud_map=", returnString))
@@ -269,6 +271,8 @@ parse(int &i, const char *line, char *&returnString)
     }
     else if (getValue(line, i, "relative_to=", returnString))
         returnVal = ORIGIN;
+    else if (getValue(line, i, "opacity=", returnString))
+        returnVal = OPACITY;
     else if (getValue(line, i, "outlined=", returnString))
         returnVal = OUTLINED;
     else if (getValue(line, i, "position=", returnString))
@@ -279,6 +283,14 @@ parse(int &i, const char *line, char *&returnString)
         returnVal = RANDOM_ORIGIN;
     else if (getValue(line, i, "random_target=", returnString))
         returnVal = RANDOM_TARGET;
+    else if (getValue(line, i, "rayleigh_emission_weight=", returnString))
+        returnVal = RAYLEIGH_EMISSION_WEIGHT;
+    else if (getValue(line, i, "rayleigh_file=", returnString))
+        returnVal = RAYLEIGH_FILE;
+    else if (getValue(line, i, "rayleigh_limb_scale=", returnString))
+        returnVal = RAYLEIGH_LIMB_SCALE;
+    else if (getValue(line, i, "rayleigh_scale=", returnString))
+        returnVal = RAYLEIGH_SCALE;
     // Any 'new' satellite_* tokens must be before this, because it
     // gobbles all forms
     else if (getValueAfter(line, i, "satellite_", '=', returnString))
