@@ -2,6 +2,8 @@
 #include <clocale>
 #include <cmath>
 #include <cstdio>
+#include <cstdlib>
+#include <cstring>
 #include <ctime>
 #include <iostream>
 #include <sstream>
@@ -146,8 +148,18 @@ ndot(const double a[3], const double b[3])
     return(dot(a, b) / sqrt(len_a * len_b));
 }
 
+double
+normalize(double a[3])
+{
+    const double length = dot(a, a);
+    if (length > 0)
+        for (int i = 0; i < 3; i++) a[i] /= length;
+
+    return(length);
+}
+
 void
-invertMatrix(double in[3][3], double out[3][3])
+invertMatrix(const double in[3][3], double out[3][3])
 {
     double a1 = in[0][0];
     double a2 = in[0][1];
@@ -161,9 +173,9 @@ invertMatrix(double in[3][3], double out[3][3])
     double c2 = in[2][1];
     double c3 = in[2][2];
 
-    double det = (a1*(b2*c3 - b3*c2) + a2*(b3*c1 - b1 * c3) 
+    double det = (a1*(b2*c3 - b3*c2) + a2*(b3*c1 - b1*c3) 
                   + a3*(b1*c2 - b2*c1));
-    
+
     out[0][0] = (b2*c3 - b3*c2)/det;
     out[0][1] = (a3*c2 - a2*c3)/det;
     out[0][2] = (a2*b3 - a3*b2)/det;
@@ -175,6 +187,39 @@ invertMatrix(double in[3][3], double out[3][3])
     out[2][0] = (b1*c2 - b2*c1)/det;
     out[2][1] = (a2*c1 - a1*c2)/det;
     out[2][2] = (a1*b2 - a2*b1)/det;
+#if 0
+    printf("in:\n");
+    for (int i = 0; i < 3; i++)
+    {
+        printf("[%14.8e, %14.8e, %14.8e],\n", in[i][0], in[i][1], 
+               in[i][2]);
+    }
+    
+    printf("det = %14.8e\n", det);
+
+    printf("out:\n");
+    for (int i = 0; i < 3; i++)
+    {
+        printf("[%14.8e, %14.8e, %14.8e],\n", out[i][0], out[i][1], 
+               out[i][2]);
+    }
+
+    printf("product:\n");
+    double prod[3][3];
+    for (int i = 0; i < 3; i++)
+    {
+        for (int j = 0; j < 3; j++) 
+        {
+            prod[i][j] = 0;
+            for (int ii = 0; ii < 3; ii++)
+                prod[i][j] += in[i][ii] * out[ii][j];
+        }
+        printf("[%14.8e, %14.8e, %14.8e],\n", prod[i][0], prod[i][1], 
+               prod[i][2]);
+    }
+
+#endif    
+
 }
 
 void
@@ -302,17 +347,20 @@ toJulian(int year, int month, int day, int hour, int min, int sec)
     return(jd);
 }
 
-// find the difference between universal and ephemeris time 
-// (delT = ET - UT)
-double 
-delT(const double jd)
+double
+deltaETpre1838(const double jd)
 {
-#if 0
     // From McCarthy & Babcock (1986)
     const double j1800 = 2378496.5;
     const double t = (jd - j1800)/36525;
     const double delT = 5.156 + 13.3066 * (t - 0.19) * (t - 0.19);
-#else
+
+    return(delT);
+}
+
+double
+deltaETpre1972(const double jd)
+{
     // Valid from 1825 to 2000, Montenbruck & Pfelger (2000), p 188
     const double T = (jd - 2451545)/36525;
     const int i = (int) floor(T/0.25);
@@ -344,9 +392,89 @@ delT(const double jd)
     const double delT = c[ii][0] + t * (c[ii][1] 
                                         + t * (c[ii][2] 
                                                + t * c[ii][3]));
-#endif
+    return delT;
+}
 
-    return(delT);
+double
+deltaETpost1972(const double jd)
+{
+    // based on JPL's leap seconds kernel file
+    const double delta_t_a = 32.184;
+    const double k = 1.657e-3;
+    const double eb = 1.671e-2;
+    const double m0 = 6.239996;
+    const double m1 = 1.99096871e-7;
+
+    // leap seconds
+    int delta_at = 9;
+    if (jd >= toJulian(1972, 1, 1, 0, 0, 0)) delta_at++; // 10
+    if (jd >= toJulian(1972, 7, 1, 0, 0, 0)) delta_at++; // 11
+    if (jd >= toJulian(1973, 1, 1, 0, 0, 0)) delta_at++; // 12
+    if (jd >= toJulian(1974, 1, 1, 0, 0, 0)) delta_at++; // 13
+    if (jd >= toJulian(1975, 1, 1, 0, 0, 0)) delta_at++; // 14
+    if (jd >= toJulian(1976, 1, 1, 0, 0, 0)) delta_at++; // 15
+    if (jd >= toJulian(1977, 1, 1, 0, 0, 0)) delta_at++; // 16
+    if (jd >= toJulian(1978, 1, 1, 0, 0, 0)) delta_at++; // 17
+    if (jd >= toJulian(1979, 1, 1, 0, 0, 0)) delta_at++; // 18
+    if (jd >= toJulian(1980, 1, 1, 0, 0, 0)) delta_at++; // 19
+    if (jd >= toJulian(1981, 7, 1, 0, 0, 0)) delta_at++; // 20
+    if (jd >= toJulian(1982, 7, 1, 0, 0, 0)) delta_at++; // 21
+    if (jd >= toJulian(1983, 7, 1, 0, 0, 0)) delta_at++; // 22
+    if (jd >= toJulian(1985, 7, 1, 0, 0, 0)) delta_at++; // 23
+    if (jd >= toJulian(1988, 1, 1, 0, 0, 0)) delta_at++; // 24
+    if (jd >= toJulian(1990, 1, 1, 0, 0, 0)) delta_at++; // 25
+    if (jd >= toJulian(1991, 1, 1, 0, 0, 0)) delta_at++; // 26
+    if (jd >= toJulian(1992, 7, 1, 0, 0, 0)) delta_at++; // 27
+    if (jd >= toJulian(1993, 7, 1, 0, 0, 0)) delta_at++; // 28
+    if (jd >= toJulian(1994, 7, 1, 0, 0, 0)) delta_at++; // 29
+    if (jd >= toJulian(1996, 1, 1, 0, 0, 0)) delta_at++; // 30
+    if (jd >= toJulian(1997, 7, 1, 0, 0, 0)) delta_at++; // 31
+    if (jd >= toJulian(1999, 1, 1, 0, 0, 0)) delta_at++; // 32
+    if (jd >= toJulian(2006, 1, 1, 0, 0, 0)) delta_at++; // 33
+    if (jd >= toJulian(2009, 1, 1, 0, 0, 0)) delta_at++; // 34
+    if (jd >= toJulian(2012, 7, 1, 0, 0, 0)) delta_at++; // 35
+    if (jd >= toJulian(2015, 7, 1, 0, 0, 0)) delta_at++; // 36
+
+    const double J2000 = toJulian(2000, 1, 1, 12, 0, 0);
+    const double m = m0 + m1 * (jd - J2000) * 86400;
+    const double e = m + eb * sin(m);
+
+    const double delT = delta_t_a + k * sin(e) + delta_at;
+    return delT;
+}
+
+// find the difference between universal and ephemeris time 
+// (delT = ET - UT)
+double 
+delT(const double jd)
+{
+    double delT;
+    if (jd < toJulian(1838, 1, 1, 0, 0, 0))
+    {
+        delT = deltaETpre1838(jd);
+    }
+    else
+    {
+        if (jd < toJulian(1972, 1, 1, 0, 0, 0))
+        {
+            delT = deltaETpre1972(jd);
+        }
+        else
+        {
+            delT = deltaETpost1972(jd);
+        }
+    }
+
+/* 
+    int year, month, day, hour, min;
+    double sec;
+    fromJulian(jd, year, month, day, hour, min, sec);
+    double thisYear = year + (month-1)/12.;
+    
+    printf("%.1f %f %f %f %f\n", thisYear, deltaETpre1838(jd), 
+           deltaETpre1972(jd), deltaETpost1972(jd), delT);
+*/    
+    return delT;
 }
 
 void 
